@@ -15,14 +15,14 @@ use strict;
     while(<FILE>)
     {
       # Look for
-      # <para><link xlink:href="&url_examples_base;helloworld">Source Code</link></para> [<!-- Insert filenames... -->]
+      # <para><ulink url="&url_examples_base;helloworld">Source Code</ulink></para> [<!-- Insert filenames... -->]
 
-      if(/<para><link xlink:href=\"&url_examples_base;([\/\w]+)\">Source Code<\/link><\/para>\s*(?:<!--\s*Insert\s+(.*?)-->)?/)
+      if(/<para><ulink url=\"&url_examples_base;([\/\w]+)\">Source Code<\/ulink><\/para>\s*(?:<!--\s*Insert\s+(.*?)-->)?/)
       {
-        # Modify the line to remove the trailing comment, if any.
-        # url_examples_base is assumed to be a GitLab URL. The branch is then
-        # included in url_examples_base. No need to add it here.
-        print "<para><link xlink:href=\"&url_examples_base;$1\">Source Code</link></para>\n";
+        #Modify the line to add the branch, so people see the correct version.
+        #This is particularly important during major API changes every few years,
+        #when the API might no longer even exist in the new version.
+        print "<para><ulink url=\"&url_examples_base;${1}?h=&url_examples_branchsuffix;\">Source Code<\/ulink><\/para>\n";
 
         #List all the source files in that directory:
         my $directory = $examples_base . $1;
@@ -70,14 +70,11 @@ sub process_source_file($$$)
   my ($directory, $source_file, $skip_leading_comments) = @_;
   my $found_start = !$skip_leading_comments;
 
-  print "<para>File: <filename>$source_file</filename> (For use with gtkmm 3, not gtkmm 2)\n";
+  print "<para>File: <filename>$source_file</filename> (For use with gtkmm 4)\n";
   print "</para>\n";
   print "<programlisting>\n";
 
-  if (!open(SOURCE_FILE, "$directory/$source_file"))
-  {
-    print STDERR "Can't open $directory/$source_file\n";
-  }
+  open(SOURCE_FILE, "$directory/$source_file");
 
   while(<SOURCE_FILE>)
   {
