@@ -33,9 +33,7 @@ protected:
   void on_open(const Gio::Application::type_vec_files& files,
     const Glib::ustring& hint) override;
   int on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine>& command_line) override;
-
-  //A regular signal handler, because there is no default signal handler for this:
-  int on_handle_local_options(const Glib::RefPtr<Glib::VariantDict>& options);
+  int on_handle_local_options(const Glib::RefPtr<Glib::VariantDict>& options) override;
 
   //Callback functions for handling some command-line arguments
   bool on_option_arg_string(const Glib::ustring& option_name,
@@ -43,13 +41,6 @@ protected:
   bool on_option_arg_filename(const Glib::ustring& option_name,
     const std::string& value, bool has_value);
 
-  // These members should live as long as the OptionGroup to which they are added,
-  // and as long as the Application to which that OptionGroup is added.
-  int m_arg_int = 0;
-  Glib::ustring m_arg_ustring;
-  bool m_arg_boolean = false;
-  Glib::OptionGroup m_option_group;
-
 private:
   void create_window(const Glib::RefPtr<Gio::File>& file = Glib::RefPtr<Gio::File>());
 
