@@ -35,7 +35,7 @@ ExampleAppWindow* ExampleAppWindow::create()
   auto refBuilder = Gtk::Builder::create_from_resource("/org/gtkmm/exampleapp/window.ui");
 
   ExampleAppWindow* window = nullptr;
-  refBuilder->get_widget_derived("app_window", window);
+  Gtk::Builder::get_widget_derived(refBuilder, "app_window", window);
   if (!window)
     throw std::runtime_error("No \"app_window\" object in window.ui");
 
@@ -44,7 +44,7 @@ ExampleAppWindow* ExampleAppWindow::create()
 
 void ExampleAppWindow::open_file_view(const Glib::RefPtr<Gio::File>& file)
 {
-  const Glib::ustring basename = file->get_basename();
+  const auto basename = file->get_basename();
 
   auto scrolled = Gtk::make_managed<Gtk::ScrolledWindow>();
   scrolled->set_hexpand(true);
