@@ -48,7 +48,7 @@ ExampleAppWindow::ExampleAppWindow(BaseObjectType* cobject,
   m_settings->bind("transition", m_stack->property_transition_type());
 
   m_prop_binding = Glib::Binding::bind_property(m_search->property_active(),
-    m_searchbar->property_search_mode_enabled(), Glib::BINDING_BIDIRECTIONAL);
+    m_searchbar->property_search_mode_enabled(), Glib::Binding::Flags::BIDIRECTIONAL);
 
   // Connect signal handlers.
   m_searchentry->signal_search_changed().connect(
@@ -64,7 +64,7 @@ ExampleAppWindow* ExampleAppWindow::create()
   auto refBuilder = Gtk::Builder::create_from_resource("/org/gtkmm/exampleapp/window.ui");
 
   ExampleAppWindow* window = nullptr;
-  refBuilder->get_widget_derived("app_window", window);
+  Gtk::Builder::get_widget_derived(refBuilder, "app_window", window);
   if (!window)
     throw std::runtime_error("No \"app_window\" object in window.ui");
 
@@ -73,7 +73,7 @@ ExampleAppWindow* ExampleAppWindow::create()
 
 void ExampleAppWindow::open_file_view(const Glib::RefPtr<Gio::File>& file)
 {
-  const Glib::ustring basename = file->get_basename();
+  const auto basename = file->get_basename();
 
   auto scrolled = Gtk::make_managed<Gtk::ScrolledWindow>();
   scrolled->set_hexpand(true);
@@ -134,7 +134,7 @@ void ExampleAppWindow::on_search_text_changed()
   auto buffer = view->get_buffer();
   Gtk::TextIter match_start;
   Gtk::TextIter match_end;
-  if (buffer->begin().forward_search(text, Gtk::TEXT_SEARCH_CASE_INSENSITIVE,
+  if (buffer->begin().forward_search(text, Gtk::TextSearchFlags::CASE_INSENSITIVE,
       match_start, match_end))
   {
     buffer->select_range(match_start, match_end);
