@@ -18,9 +18,6 @@
 #include <iostream>
 #include <cstring>
 
-// Not really used anywhere, but force an instance to be created.
-DerivedButton* my_globally_accessible_button = nullptr;
-
 int main (int argc, char **argv)
 {
   bool show_icon = false;
@@ -42,11 +39,7 @@ int main (int argc, char **argv)
     }
   }
 
-  auto app = Gtk::Application::create(argc1, argv, "org.gtkmm.example");
-
-  // Create a dummy instance before the call to refBuilder->add_from_file().
-  // This creation registers DerivedButton's class in the GType system.
-  my_globally_accessible_button = new DerivedButton();
+  auto app = Gtk::Application::create("org.gtkmm.example");
 
   //Load the Glade file and instantiate its widgets:
   auto refBuilder = Gtk::Builder::create();
@@ -74,13 +67,13 @@ int main (int argc, char **argv)
   DerivedDialog* pDialog = nullptr;
   if (show_icon)
     // This call to get_widget_derived() requires gtkmm 3.19.7 or higher.
-    refBuilder->get_widget_derived("DialogDerived", pDialog, is_glad);
+    Gtk::Builder::get_widget_derived(refBuilder, "DialogDerived", pDialog, is_glad);
   else
-    refBuilder->get_widget_derived("DialogDerived", pDialog);
+    Gtk::Builder::get_widget_derived(refBuilder, "DialogDerived", pDialog);
   if(pDialog)
   {
     //Start:
-    app->run(*pDialog);
+    app->run(*pDialog, argc1, argv);
   }
 
   delete pDialog;
