@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 341 2005-01-18 20:52:18Z murrayc $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2004 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,25 +17,27 @@
 #include "examplewindow.h"
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
-  m_Button_Quit("Quit")
+: m_Button_Quit("Quit")
 {
   set_title("Custom Widget example");
-  set_border_width(6);
-  set_default_size(400, 200);
+  set_default_size(600, 400);
 
-  add(m_VBox);
-  m_VBox.pack_start(m_MyWidget, Gtk::PACK_EXPAND_WIDGET);
-  m_MyWidget.show();
+  m_Grid.set_margin(6);
+  m_Grid.set_row_spacing(10);
+  m_Grid.set_column_spacing(10);
 
-  m_VBox.pack_start(m_ButtonBox, Gtk::PACK_SHRINK);
+  add(m_Grid);
 
-  m_ButtonBox.pack_start(m_Button_Quit, Gtk::PACK_SHRINK);
-  m_ButtonBox.set_border_width(6);
-  m_ButtonBox.set_layout(Gtk::BUTTONBOX_END);
+  m_Grid.attach(m_MyWidgetS1, 0, 0);
+  m_Grid.attach(m_MyWidgetS2, 1, 1);
+
+  m_Grid.attach(m_ButtonBox, 0, 2, 2, 1);
+
+  m_ButtonBox.add(m_Button_Quit);
+  m_ButtonBox.set_margin(6);
+  m_Button_Quit.set_hexpand(true);
+  m_Button_Quit.set_halign(Gtk::Align::END);
   m_Button_Quit.signal_clicked().connect( sigc::mem_fun(*this, &ExampleWindow::on_button_quit) );
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
