@@ -16,13 +16,6 @@
 #ifndef GTKMM_CUSTOM_WIDGET_MYEXTRAINIT_H
 #define GTKMM_CUSTOM_WIDGET_MYEXTRAINIT_H
 
-#include <glibmmconfig.h>
-
-#define HAS_EXTRA_CLASS_INIT (GLIBMM_MAJOR_VERSION > 2 || \
-  (GLIBMM_MAJOR_VERSION == 2 && GLIBMM_MINOR_VERSION >= 60))
-
-#if HAS_EXTRA_CLASS_INIT
-
 #include <glibmm/extraclassinit.h>
 #include <glibmm/ustring.h>
 
@@ -37,6 +30,4 @@ private:
   Glib::ustring m_css_name;
 };
 
-#endif // HAS_EXTRA_CLASS_INIT
-
 #endif //GTKMM_CUSTOM_WIDGET_MYEXTRAINIT_H
