@@ -16,33 +16,25 @@
 
 #include "mywidget.h"
 #include <gdkmm/general.h>  // for cairo helper functions
+#include <gtkmm/container.h>
+#include <gtkmm/snapshot.h>
 #include <iostream>
 //#include <gtk/gtkwidget.h> //For GTK_IS_WIDGET()
 #include <cstring>
 
-// The MyWidget class uses API which was added in gtkmm 3.15.3 (Gtk::CssProviderError,
-// Gtk::CssProvider::signal_parsing_error() and Gtk::CssSection) and in gtkmm 3.15.2
-// (Gtk::StyleProperty) and in glibmm 2.60.0 (Glib::ExtraClassInit).
 
 MyWidget::MyWidget() :
-  //The GType name will actually be gtkmm__CustomObject_mywidget
-  Glib::ObjectBase("mywidget"),
-#if HAS_EXTRA_CLASS_INIT
-  MyExtraInit("my-widget-class"), // CSS node name, which must be used in the CSS file.
-#endif
+  //The GType name will actually be gtkmm__CustomObject_MyWidget
+  Glib::ObjectBase("MyWidget"),
+  MyExtraInit("my-widget"), // CSS node name, which must be used in the CSS file.
   Gtk::Widget(),
-  //Install a style property so that an aspect of this widget may be themed
-  //via a CSS style sheet file:
-  m_scale_prop(*this, "example_scale", 500),
-  m_scale(1000)
+  m_padding()
 {
-#if HAS_EXTRA_CLASS_INIT == 0
-  set_has_window(true);
-  // Set the widget name to use in the CSS file.
-  set_name("my-widget-instance");
-#endif
+  // Expand, if there is extra space.
+  set_hexpand(true);
+  set_vexpand(true);
 
-  //This shows the GType name, which must be used in the CSS file.
+  //This shows the GType name.
   std::cout << "GType name: " << G_OBJECT_TYPE_NAME(gobj()) << std::endl;
 
   //This shows that the GType still derives from GtkWidget:
@@ -52,8 +44,8 @@ MyWidget::MyWidget() :
   // - for a GType (in this case for your custom class) with gtk_widget_class_set_css_name(), or
   // - for a widget instance with gtk_widget_set_name() (Gtk::Widget::set_name()).
   //
-  // gtk_widget_class_set_css_name() (new in gtk+ 3.19.1), if used, must be called
-  // in the class init function. It has not been wrapped in a C++ function.
+  // gtk_widget_class_set_css_name(), if used, must be called in the class init function.
+  // It has not been wrapped in a C++ function.
   // Gtk::Widget::set_name() can be called in a C++ constructor.
   //
   // Another alternative: The custom widget inherits the CSS name "widget" from
@@ -68,20 +60,7 @@ MyWidget::MyWidget() :
   m_refCssProvider->signal_parsing_error().connect(
     sigc::mem_fun(*this, &MyWidget::on_parsing_error));
 
-  try
-  {
-    m_refCssProvider->load_from_path("custom_gtk.css");
-  }
-  catch(const Gtk::CssProviderError& ex)
-  {
-    std::cerr << "CssProviderError, Gtk::CssProvider::load_from_path() failed: "
-              << ex.what() << std::endl;
-  }
-  catch(const Glib::Error& ex)
-  {
-    std::cerr << "Error, Gtk::CssProvider::load_from_path() failed: "
-              << ex.what() << std::endl;
-  }
+  m_refCssProvider->load_from_path("custom_gtk.css");
 }
 
 MyWidget::~MyWidget()
@@ -98,45 +77,34 @@ Gtk::SizeRequestMode MyWidget::get_request_mode_vfunc() const
 //this widget.
 //Let's make this simple example widget always need minimum 60 by 50 and
 //natural 100 by 70.
-void MyWidget::get_preferred_width_vfunc(int& minimum_width, int& natural_width) const
+void MyWidget::measure_vfunc(Gtk::Orientation orientation, int /* for_size */,
+  int& minimum, int& natural, int& minimum_baseline, int& natural_baseline) const
 {
-  minimum_width = 60;
-  natural_width = 100;
+  if (orientation == Gtk::Orientation::HORIZONTAL)
+  {
+    minimum = 60;
+    natural = 100;
+  }
+  else
+  {
+    minimum = 50;
+    natural = 70;
+  }
+
+  // Don't use baseline alignment.
+  minimum_baseline = -1;
+  natural_baseline = -1;
 }
 
-void MyWidget::get_preferred_height_for_width_vfunc(int /* width */,
-   int& minimum_height, int& natural_height) const
-{
-  minimum_height = 50;
-  natural_height = 70;
-}
-
-void MyWidget::get_preferred_height_vfunc(int& minimum_height, int& natural_height) const
-{
-  minimum_height = 50;
-  natural_height = 70;
-}
-
-void MyWidget::get_preferred_width_for_height_vfunc(int /* height */,
-   int& minimum_width, int& natural_width) const
-{
-  minimum_width = 60;
-  natural_width = 100;
-}
-
-void MyWidget::on_size_allocate(Gtk::Allocation& allocation)
+void MyWidget::on_size_allocate(int width, int height, int /* baseline */)
 {
   //Do something with the space that we have actually been given:
   //(We will not be given heights or widths less than we have requested, though
   //we might get more)
 
-  //Use the offered allocation for this container:
-  set_allocation(allocation);
-
-  if(m_refGdkWindow)
+  if(m_refGdkSurface)
   {
-    m_refGdkWindow->move_resize( allocation.get_x(), allocation.get_y(),
-            allocation.get_width(), allocation.get_height() );
+    m_refGdkSurface->move_resize(0, 0, width, height);
   }
 }
 
@@ -154,67 +122,54 @@ void MyWidget::on_unmap()
 
 void MyWidget::on_realize()
 {
-  //Do not call base class Gtk::Widget::on_realize().
-  //It's intended only for widgets that set_has_window(false).
+  //Get the themed padding from the CSS file:
+  m_padding = get_style_context()->get_padding();
+  std::cout << "m_padding from the theme/css-file is"
+    << ": top=" << m_padding.get_top()
+    << ", right=" << m_padding.get_right()
+    << ", bottom=" << m_padding.get_bottom()
+    << ", left=" << m_padding.get_left() << std::endl;
 
-  set_realized();
-
-  //Get the themed style from the CSS file:
-  m_scale = m_scale_prop.get_value();
-  std::cout << "m_scale (example_scale from the theme/css-file) is: "
-      << m_scale << std::endl;
-
-  if(!m_refGdkWindow)
+  if(!m_refGdkSurface)
   {
-    //Create the GdkWindow:
+    //Create the GdkSurface:
+    m_refGdkSurface = Gdk::Surface::create_child(get_parent()->get_surface(), get_allocation());
+    set_surface(m_refGdkSurface);
 
-    GdkWindowAttr attributes;
-    memset(&attributes, 0, sizeof(attributes));
-
-    Gtk::Allocation allocation = get_allocation();
-
-    //Set initial position and size of the Gdk::Window:
-    attributes.x = allocation.get_x();
-    attributes.y = allocation.get_y();
-    attributes.width = allocation.get_width();
-    attributes.height = allocation.get_height();
-
-    attributes.event_mask = get_events () | Gdk::EXPOSURE_MASK;
-    attributes.window_type = GDK_WINDOW_CHILD;
-    attributes.wclass = GDK_INPUT_OUTPUT;
-
-    m_refGdkWindow = Gdk::Window::create(get_parent_window(), &attributes,
-            GDK_WA_X | GDK_WA_Y);
-    set_window(m_refGdkWindow);
-
-    //make the widget receive expose events
-    m_refGdkWindow->set_user_data(gobj());
+    // Make the widget receive expose events
+    register_surface(m_refGdkSurface);
   }
+
+  //Call base class:
+  Gtk::Widget::on_realize();
 }
 
 void MyWidget::on_unrealize()
 {
-  m_refGdkWindow.reset();
+  m_refGdkSurface.reset();
 
   //Call base class:
   Gtk::Widget::on_unrealize();
 }
 
-bool MyWidget::on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
+void MyWidget::snapshot_vfunc(const Glib::RefPtr<Gtk::Snapshot>& snapshot)
 {
-  const Gtk::Allocation allocation = get_allocation();
-  const double scale_x = (double)allocation.get_width() / m_scale;
-  const double scale_y = (double)allocation.get_height() / m_scale;
+  const auto allocation = get_allocation();
+  const Gdk::Rectangle rect(0, 0, allocation.get_width(), allocation.get_height());
   auto refStyleContext = get_style_context();
 
+  // Create a cairo context to draw on.
+  auto cr = snapshot->append_cairo(rect);
+
   // paint the background
   refStyleContext->render_background(cr,
-    allocation.get_x(), allocation.get_y(),
-    allocation.get_width(), allocation.get_height());
+    -m_padding.get_left(), -m_padding.get_top(), allocation.get_width(), allocation.get_height());
 
   // draw the foreground
-  const auto state = refStyleContext->get_state();
-  Gdk::Cairo::set_source_rgba(cr, refStyleContext->get_color(state));
+  const double scale_x = 0.001 * (allocation.get_width() - m_padding.get_left() - m_padding.get_right());
+  const double scale_y = 0.001 * (allocation.get_height() - m_padding.get_top() - m_padding.get_bottom());
+  Gdk::Cairo::set_source_rgba(cr, refStyleContext->get_color());
+  cr->rectangle(0.0, 0.0, 1000.0*scale_x, 1000.0*scale_y);
   cr->move_to(155.*scale_x, 165.*scale_y);
   cr->line_to(155.*scale_x, 838.*scale_y);
   cr->line_to(265.*scale_x, 900.*scale_y);
@@ -234,8 +189,6 @@ bool MyWidget::on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
   cr->move_to(633.*scale_x, 564.*scale_y);
   cr->line_to(155.*scale_x, 838.*scale_y);
   cr->stroke();
-
-  return true;
 }
 
 void MyWidget::on_parsing_error(const Glib::RefPtr<const Gtk::CssSection>& section, const Glib::Error& error)
@@ -249,9 +202,11 @@ void MyWidget::on_parsing_error(const Glib::RefPtr<const Gtk::CssSection>& secti
       std::cerr << "  URI = " << file->get_uri() << std::endl;
     }
 
-    std::cerr << "  start_line = " << section->get_start_line()+1
-              << ", end_line = " << section->get_end_line()+1 << std::endl;
-    std::cerr << "  start_position = " << section->get_start_position()
-              << ", end_position = " << section->get_end_position() << std::endl;
+    auto start_location = section->get_start_location();
+    auto end_location = section->get_end_location();
+    std::cerr << "  start_line = " << start_location.get_lines()+1
+              << ", end_line = " << end_location.get_lines()+1 << std::endl;
+    std::cerr << "  start_position = " << start_location.get_line_chars()
+              << ", end_position = " << end_location.get_line_chars() << std::endl;
   }
 }
