@@ -19,14 +19,12 @@
 
 #include <gtkmm/widget.h>
 #include <gtkmm/cssprovider.h>
-#include <gtkmm/styleproperty.h>
 #include "myextrainit.h"
 
-#if HAS_EXTRA_CLASS_INIT
-class MyWidget : public MyExtraInit, public Gtk::Widget
-#else
-class MyWidget : public Gtk::Widget
-#endif
+class MyWidget
+:
+public MyExtraInit,
+public Gtk::Widget
 {
 public:
   MyWidget();
@@ -36,25 +34,21 @@ protected:
 
   //Overrides:
   Gtk::SizeRequestMode get_request_mode_vfunc() const override;
-  void get_preferred_width_vfunc(int& minimum_width, int& natural_width) const override;
-  void get_preferred_height_for_width_vfunc(int width, int& minimum_height, int& natural_height) const  override;
-  void get_preferred_height_vfunc(int& minimum_height, int& natural_height) const override;
-  void get_preferred_width_for_height_vfunc(int height, int& minimum_width, int& natural_width) const override;
-  void on_size_allocate(Gtk::Allocation& allocation) override;
+  void measure_vfunc(Gtk::Orientation orientation, int for_size, int& minimum, int& natural,
+    int& minimum_baseline, int& natural_baseline) const override;
+  void on_size_allocate(int width, int height, int baseline) override;
   void on_map() override;
   void on_unmap() override;
   void on_realize() override;
   void on_unrealize() override;
-  bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr) override;
+  void snapshot_vfunc(const Glib::RefPtr<Gtk::Snapshot>& snapshot) override;
 
   //Signal handler:
   void on_parsing_error(const Glib::RefPtr<const Gtk::CssSection>& section, const Glib::Error& error);
 
-  Gtk::StyleProperty<int> m_scale_prop;
-  Glib::RefPtr<Gdk::Window> m_refGdkWindow;
+  Gtk::Border m_padding;
+  Glib::RefPtr<Gdk::Surface> m_refGdkSurface;
   Glib::RefPtr<Gtk::CssProvider> m_refCssProvider;
-
-  int m_scale;
 };
 
 #endif //GTKMM_CUSTOM_WIDGET_MYWIDGET_H
