@@ -18,28 +18,33 @@
 #include <iostream>
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
+: m_VBox(Gtk::Orientation::VERTICAL),
   m_Label("The AboutDialog is non-modal. "
     "You can select parts of this text while the AboutDialog is shown."),
-  m_ButtonBox(Gtk::ORIENTATION_VERTICAL),
+  m_ButtonBox(Gtk::Orientation::VERTICAL),
   m_Button("Show AboutDialog")
 {
   set_title("Gtk::AboutDialog example");
 
   add(m_VBox);
 
-  m_VBox.pack_start(m_Label);
+  m_VBox.add(m_Label);
+  m_Label.set_expand(true);
   m_Label.set_line_wrap(true);
   m_Label.set_selectable(true);
 
-  m_VBox.pack_start(m_ButtonBox);
-  m_ButtonBox.pack_start(m_Button);
+  m_VBox.add(m_ButtonBox);
+  m_ButtonBox.add(m_Button);
+  m_Button.set_expand(true);
+  m_Button.set_halign(Gtk::Align::CENTER);
+  m_Button.set_valign(Gtk::Align::CENTER);
   m_Button.signal_clicked().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_button_clicked) );
 
   m_Dialog.set_transient_for(*this);
 
-  m_Dialog.set_logo(Gdk::Pixbuf::create_from_resource("/about/gtkmm_logo.gif", -1, 40, true));
+  m_Dialog.set_logo(Gdk::Texture::create_for_pixbuf(
+    Gdk::Pixbuf::create_from_resource("/about/gtkmm_logo.gif", -1, 40, true)));
   m_Dialog.set_program_name("Example application");
   m_Dialog.set_version("1.0.0");
   m_Dialog.set_copyright("Murray Cumming");
@@ -58,31 +63,26 @@ ExampleWindow::ExampleWindow()
   m_Dialog.signal_response().connect(
     sigc::mem_fun(*this, &ExampleWindow::on_about_dialog_response) );
 
-  show_all_children();
-
-  // The widget must be realized and mapped before grab_focus() is called.
-  // That's why it's called after show_all_children().
   m_Button.grab_focus();
 }
 
 ExampleWindow::~ExampleWindow()
 {
-
 }
 
 void ExampleWindow::on_about_dialog_response(int response_id)
 {
   std::cout << response_id
-    << ", close=" << Gtk::RESPONSE_CLOSE
-    << ", cancel=" << Gtk::RESPONSE_CANCEL
-    << ", delete_event=" << Gtk::RESPONSE_DELETE_EVENT
+    << ", close=" << Gtk::ResponseType::CLOSE
+    << ", cancel=" << Gtk::ResponseType::CANCEL
+    << ", delete_event=" << Gtk::ResponseType::DELETE_EVENT
     << std::endl;
 
   switch (response_id)
   {
-  case Gtk::RESPONSE_CLOSE:
-  case Gtk::RESPONSE_CANCEL:
-  case Gtk::RESPONSE_DELETE_EVENT:
+  case Gtk::ResponseType::CLOSE:
+  case Gtk::ResponseType::CANCEL:
+  case Gtk::ResponseType::DELETE_EVENT:
     m_Dialog.hide();
     break;
   default:
