@@ -26,10 +26,10 @@ public:
 
 protected:
   // Signal handlers:
-  void on_button_file_clicked(Gtk::FileChooserAction action);
+  void on_button_file_clicked(Gtk::FileChooser::Action action);
 
   // Child widgets:
-  Gtk::ButtonBox m_ButtonBox;
+  Gtk::Box m_ButtonBox;
   Gtk::Button m_Button_File_Open;
   Gtk::Button m_Button_File_Save;
 };
