@@ -1,5 +1,3 @@
-//$Id: dndwindow.h 839 2007-05-10 04:11:54Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,11 +32,11 @@ public:
 protected:
   //Signal handlers:
   void on_button_drag_data_get(
-          const Glib::RefPtr<Gdk::DragContext>& context,
-          Gtk::SelectionData& selection_data, guint info, guint time);
+          const Glib::RefPtr<Gdk::Drag>& drag,
+          Gtk::SelectionData& selection_data);
   void on_label_drop_drag_data_received(
-          const Glib::RefPtr<Gdk::DragContext>& context, int x, int y,
-          const Gtk::SelectionData& selection_data, guint info, guint time);
+          const Glib::RefPtr<Gdk::Drop>& drop,
+          const Gtk::SelectionData& selection_data);
 
   //Member widgets:
   Gtk::Box m_HBox;
