@@ -1,3 +1,4 @@
+#include <build/config.h>
 #include <gtkmm/application.h>
 #include <glibmm/main.h>
 #include <glibmm/iochannel.h>
@@ -28,7 +29,7 @@ Glib::RefPtr<Glib::IOChannel> iochannel;
 // and quit the program if the message was 'Q'.
 bool MyCallback(Glib::IOCondition io_condition)
 {
-  if ((io_condition & Glib::IO_IN) == 0) {
+  if ((io_condition & Glib::IOCondition::IO_IN) != Glib::IOCondition::IO_IN) {
     std::cerr << "Invalid fifo response" << std::endl;
   }
   else {
@@ -46,11 +47,11 @@ bool MyCallback(Glib::IOCondition io_condition)
 
 int main(int argc, char *argv[])
 {
-  app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
+  app = Gtk::Application::create("org.gtkmm.example");
 
   if (access("testfifo", F_OK) == -1) {
     // fifo doesn't exist - create it
-    #ifndef DONT_HAVE_MKFIFO
+    #ifdef HAVE_MKFIFO
     if (mkfifo("testfifo", 0666) != 0) {
       std::cerr << "error creating fifo" << std::endl;
       return -1;
@@ -58,7 +59,7 @@ int main(int argc, char *argv[])
     #else
       std::cerr << "error creating fifo: This platform does not have mkfifo()"
           << std::endl;
-    #endif //DONT_HAVE_MKFIFO
+    #endif //HAVE_MKFIFO
   }
 
   // Although we will only read from the fifo, we open it in read/write mode.
@@ -75,14 +76,14 @@ int main(int argc, char *argv[])
   }
 
   // connect the signal handler
-  Glib::signal_io().connect(sigc::ptr_fun(MyCallback), read_fd, Glib::IO_IN);
+  Glib::signal_io().connect(sigc::ptr_fun(MyCallback), read_fd, Glib::IOCondition::IO_IN);
 
   // Creates a iochannel from the file descriptor
   iochannel = Glib::IOChannel::create_from_fd(read_fd);
 
   // and last but not least - run the application main loop
   app->hold(); // keep the application running without a window
-  app->run();
+  app->run(argc, argv);
 
   // now remove the temporary fifo
   if(unlink("testfifo"))
