@@ -1,5 +1,3 @@
-//$Id: examplewindow.h 705 2006-07-19 02:55:32Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,8 +19,6 @@
 
 #include <gtkmm.h>
 
-#include <memory>
-
 class ExampleWindow : public Gtk::Window
 {
 public:
@@ -31,18 +27,18 @@ public:
 
 protected:
   //Signal handlers:
-  bool on_button_press_event(GdkEventButton* button_event) override;
+  void on_label_pressed(int n_press, double x, double y);
 
   void on_menu_file_popup_generic();
 
   //Child widgets:
   Gtk::Box m_Box;
-  Gtk::EventBox m_EventBox;
   Gtk::Label m_Label;
 
   Glib::RefPtr<Gtk::Builder> m_refBuilder;
+  Glib::RefPtr<Gtk::GestureMultiPress> m_refGesture;
 
-  std::unique_ptr<Gtk::Menu> m_pMenuPopup;
+  Gtk::Menu* m_pMenuPopup;
 };
 
 #endif //GTKMM_EXAMPLEWINDOW_H
