@@ -17,7 +17,7 @@
 #include "examplewindow.h"
 
 ExampleWindow::ExampleWindow()
- : m_format_buttons_box(Gtk::ORIENTATION_HORIZONTAL),
+ : m_format_buttons_box(Gtk::Orientation::HORIZONTAL),
    m_toggle_button("Button"),
    m_toggle_form_popover(m_toggle_button),
    m_toggle_form_label("Non-modal Popover"),
@@ -27,7 +27,6 @@ ExampleWindow::ExampleWindow()
 {
   // Window properties
   set_title("Popover Example");
-  set_border_width(12);
   set_default_size(500, -1);
 
   // Button
@@ -37,8 +36,7 @@ ExampleWindow::ExampleWindow()
   configure_form_popover();
 
   // Calendar
-  m_calendar.set_hexpand();
-  m_calendar.set_vexpand();
+  m_calendar.set_expand();
 
   // Calendar popover
   configure_cal_popover();
@@ -47,9 +45,8 @@ ExampleWindow::ExampleWindow()
   m_grid.set_row_spacing(6);
   m_grid.attach(m_toggle_button, 0, 0, 1, 1);
   m_grid.attach(m_calendar, 0, 1, 6, 1);
+  m_grid.set_margin(12);
   add(m_grid);
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
@@ -73,32 +70,28 @@ void ExampleWindow::configure_form_popover()
   m_toggle_form_grid.attach(m_format_buttons_box, 0, 1, 2, 1);
   m_toggle_form_grid.attach(m_toggle_form_combo_label, 0, 2, 1, 1);
   m_toggle_form_grid.attach(m_toggle_form_combo, 1, 2, 1, 1);
-  m_toggle_form_grid.show_all();
 
   m_toggle_form_popover.add(m_toggle_form_grid);
-  m_toggle_form_popover.set_position(Gtk::POS_BOTTOM);
-  m_toggle_form_popover.set_border_width(6);
+  m_toggle_form_popover.set_position(Gtk::PositionType::BOTTOM);
+  m_toggle_form_popover.set_margin(6);
   m_toggle_form_popover.set_modal(false);
 }
 
 void ExampleWindow::configure_form_buttons()
 {
-  m_toggle_form_buttons[0].set_image_from_icon_name("format-justify-left-symbolic", Gtk::ICON_SIZE_BUTTON, true);
-  m_toggle_form_buttons[1].set_image_from_icon_name("format-justify-center-symbolic", Gtk::ICON_SIZE_BUTTON, true);
-  m_toggle_form_buttons[2].set_image_from_icon_name("format-justify-right-symbolic", Gtk::ICON_SIZE_BUTTON, true);
-
-  m_toggle_form_buttons[0].set_mode(false);
-  m_toggle_form_buttons[1].set_mode(false);
-  m_toggle_form_buttons[2].set_mode(false);
+  m_toggle_form_buttons[0].set_image_from_icon_name("format-justify-left-symbolic", Gtk::IconSize::INHERIT, true);
+  m_toggle_form_buttons[1].set_image_from_icon_name("format-justify-center-symbolic", Gtk::IconSize::INHERIT, true);
+  m_toggle_form_buttons[2].set_image_from_icon_name("format-justify-right-symbolic", Gtk::IconSize::INHERIT, true);
 
   m_toggle_form_buttons[1].join_group(m_toggle_form_buttons[0]);
   m_toggle_form_buttons[2].join_group(m_toggle_form_buttons[0]);
 
-  m_format_buttons_box.pack_start(m_toggle_form_buttons[0], Gtk::PACK_EXPAND_WIDGET);
-  m_format_buttons_box.pack_start(m_toggle_form_buttons[1], Gtk::PACK_EXPAND_WIDGET);
-  m_format_buttons_box.pack_start(m_toggle_form_buttons[2], Gtk::PACK_EXPAND_WIDGET);
-
-  m_format_buttons_box.set_hexpand();
+  for (auto& button : m_toggle_form_buttons)
+  {
+    button.set_draw_indicator(false);
+    button.set_expand(true);
+    m_format_buttons_box.add(button);
+  }
 
   // Group format buttons so that they appear that they belong together
   auto style_context = m_format_buttons_box.get_style_context();
@@ -122,11 +115,11 @@ void ExampleWindow::on_combo_changed()
 
   if (active_entry == 0)
   {
-    m_toggle_form_popover.set_position(Gtk::POS_BOTTOM);
+    m_toggle_form_popover.set_position(Gtk::PositionType::BOTTOM);
   }
   else if (active_entry == 1)
   {
-    m_toggle_form_popover.set_position(Gtk::POS_RIGHT);
+    m_toggle_form_popover.set_position(Gtk::PositionType::RIGHT);
   }
 }
 
@@ -137,29 +130,34 @@ void ExampleWindow::configure_cal_popover()
   m_calendar_form_grid.set_column_spacing(6);
   m_calendar_form_grid.attach(m_calendar_popover_label, 0, 0, 1, 1);
   m_calendar_form_grid.attach(m_calendar_popover_entry, 1, 0, 1, 1);
-  m_calendar_form_grid.show_all();
 
   m_calendar_popover.add(m_calendar_form_grid);
-  m_calendar_popover.set_border_width(6);
+  m_calendar_popover.set_margin(6);
 }
 
 void ExampleWindow::on_day_selected()
 {
-  Gdk::Rectangle rect;
+  auto current_event = Glib::wrap(gtk_get_current_event(), false);
 
-  auto current_event = gtk_get_current_event();
-
-  if (current_event->type != GDK_BUTTON_PRESS)
+  if (current_event->get_event_type() != Gdk::Event::Type::BUTTON_PRESS)
   {
     return;
   }
 
-  gdk_window_coords_to_parent (current_event->button.window,
-                               current_event->button.x, current_event->button.y,
-                               &current_event->button.x, &current_event->button.y);
-  Gtk::Allocation allocation = m_calendar.get_allocation();
-  rect.set_x(current_event->button.x - allocation.get_x());
-  rect.set_y(current_event->button.y - allocation.get_y());
+  // The event is a GdkEventButton.
+  // This suspicious-looking cast is okay because Gdk::EventButton
+  // does not add any data members to those of Gdk::Event.
+  const Glib::RefPtr<Gdk::EventButton> current_event_button =
+    std::static_pointer_cast<Gdk::EventButton>(current_event);
+
+  double x = 0.0;
+  double y = 0.0;
+  current_event_button->get_coords(x, y);
+  current_event_button->get_surface()->coords_to_parent(x, y, x, y);
+  Gdk::Rectangle rect;
+  auto allocation = m_calendar.get_allocation();
+  rect.set_x(x - allocation.get_x());
+  rect.set_y(y - allocation.get_y());
   rect.set_width(1);
   rect.set_height(1);
 
@@ -167,7 +165,5 @@ void ExampleWindow::on_day_selected()
   m_calendar_popover.set_visible(true);
 
   m_calendar_popover_entry.set_text("");
-
-  gdk_event_free (current_event);
 }
 
