@@ -23,7 +23,7 @@
 const Glib::ustring app_title = "gtkmm Printing Example";
 
 ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
+: m_VBox(Gtk::Orientation::VERTICAL),
   m_NameLabel("Name"),
   m_SurnameLabel("Surname"),
   m_CommentsLabel("Comments")
@@ -40,34 +40,33 @@ ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
 
   build_main_menu(app);
 
-  m_VBox.pack_start(m_Grid);
+  m_VBox.add(m_Grid);
 
   //Arrange the widgets inside the grid:
+  m_Grid.set_expand(true);
   m_Grid.set_row_spacing(5);
   m_Grid.set_column_spacing(5);
-  m_Grid.attach(m_NameLabel, 0, 0, 1, 1);
-  m_Grid.attach(m_NameEntry, 1, 0, 1, 1);
+  m_Grid.attach(m_NameLabel, 0, 0);
+  m_Grid.attach(m_NameEntry, 1, 0);
 
-  m_Grid.attach(m_SurnameLabel, 0, 1, 1, 1);
-  m_Grid.attach(m_SurnameEntry, 1, 1, 1, 1);
+  m_Grid.attach(m_SurnameLabel, 0, 1);
+  m_Grid.attach(m_SurnameEntry, 1, 1);
 
   //Add the TextView, inside a ScrolledWindow:
   m_ScrolledWindow.add(m_TextView);
 
   //Only show the scrollbars when they are necessary:
-  m_ScrolledWindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+  m_ScrolledWindow.set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
 
-  m_Grid.attach(m_CommentsLabel, 0, 2, 1, 1);
-  m_Grid.attach(m_ScrolledWindow, 1, 2, 1, 1);
-  m_ScrolledWindow.set_hexpand(true);
-  m_ScrolledWindow.set_vexpand(true);
+  m_Grid.attach(m_CommentsLabel, 0, 2);
+  m_Grid.attach(m_ScrolledWindow, 1, 2);
+  m_ScrolledWindow.set_expand(true);
 
   m_refTextBuffer = Gtk::TextBuffer::create();
   m_TextView.set_buffer(m_refTextBuffer);
 
-  m_VBox.pack_start(m_Statusbar);
-
-  show_all_children();
+  m_Statusbar.set_expand(true);
+  m_VBox.add(m_Statusbar);
 }
 
 ExampleWindow::~ExampleWindow()
@@ -154,60 +153,47 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
 
   // Layout the actions in a toolbar:
   Glib::ustring ui_toolbar_info =
-    "<!-- Generated with glade 3.18.3 -->"
+    "<!-- Generated with glade 3.18.3 and then changed manually -->"
     "<interface>"
-      "<requires lib='gtk+' version='3.8'/>"
+      "<requires lib='gtk' version='3.94'/>"
       "<object class='GtkToolbar' id='toolbar'>"
-        "<property name='visible'>True</property>"
         "<property name='can_focus'>False</property>"
         "<child>"
           "<object class='GtkToolButton' id='toolbutton_new'>"
-            "<property name='visible'>True</property>"
             "<property name='can_focus'>False</property>"
             "<property name='tooltip_text' translatable='yes'>New</property>"
             "<property name='action_name'>example.new</property>"
             "<property name='icon_name'>document-new</property>"
-          "</object>"
-          "<packing>"
             "<property name='expand'>False</property>"
             "<property name='homogeneous'>True</property>"
-          "</packing>"
+          "</object>"
         "</child>"
         "<child>"
           "<object class='GtkToolButton' id='toolbutton_print'>"
-            "<property name='visible'>True</property>"
             "<property name='can_focus'>False</property>"
             "<property name='tooltip_text' translatable='yes'>Print</property>"
             "<property name='action_name'>example.print</property>"
             "<property name='icon_name'>document-print</property>"
-          "</object>"
-          "<packing>"
             "<property name='expand'>False</property>"
             "<property name='homogeneous'>True</property>"
-          "</packing>"
+          "</object>"
         "</child>"
         "<child>"
           "<object class='GtkSeparatorToolItem' id='separator1'>"
-            "<property name='visible'>True</property>"
             "<property name='can_focus'>False</property>"
-          "</object>"
-          "<packing>"
             "<property name='expand'>False</property>"
             "<property name='homogeneous'>False</property>"
-          "</packing>"
+          "</object>"
         "</child>"
         "<child>"
           "<object class='GtkToolButton' id='toolbutton_quit'>"
-            "<property name='visible'>True</property>"
             "<property name='can_focus'>False</property>"
             "<property name='tooltip_text' translatable='yes'>Quit</property>"
             "<property name='action_name'>example.quit</property>"
             "<property name='icon_name'>application-exit</property>"
-          "</object>"
-          "<packing>"
             "<property name='expand'>False</property>"
             "<property name='homogeneous'>True</property>"
-          "</packing>"
+          "</object>"
         "</child>"
       "</object>"
     "</interface>";
@@ -223,7 +209,7 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
 
   // Get the menubar and add it to a container widget:
   auto object = m_refBuilder->get_object("menu-example");
-  auto gmenu = Glib::RefPtr<Gio::Menu>::cast_dynamic(object);
+  auto gmenu = std::dynamic_pointer_cast<Gio::Menu>(object);
   if (!gmenu)
     g_warning("GMenu not found");
   else
@@ -231,7 +217,7 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
     auto pMenuBar = Gtk::make_managed<Gtk::MenuBar>(gmenu);
 
     // Add the MenuBar to the window:
-    m_VBox.pack_start(*pMenuBar, Gtk::PACK_SHRINK);
+    m_VBox.add(*pMenuBar);
   }
 
   // Get the toolbar and add it to a container widget:
@@ -240,7 +226,7 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
   if (!toolbar)
     g_warning("GtkToolbar not found");
   else
-    m_VBox.pack_start(*toolbar, Gtk::PACK_SHRINK);
+    m_VBox.add(*toolbar);
 }
 
 void ExampleWindow::on_printoperation_status_changed()
@@ -260,17 +246,17 @@ void ExampleWindow::on_printoperation_status_changed()
   m_Statusbar.push(status_msg, m_ContextId);
 }
 
-void ExampleWindow::on_printoperation_done(Gtk::PrintOperationResult result)
+void ExampleWindow::on_printoperation_done(Gtk::PrintOperation::Result result)
 {
   //Printing is "done" when the print data is spooled.
 
-  if (result == Gtk::PRINT_OPERATION_RESULT_ERROR)
+  if (result == Gtk::PrintOperation::Result::ERROR)
   {
     Gtk::MessageDialog err_dialog(*this, "Error printing form", false,
-            Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK, true);
+            Gtk::MessageType::ERROR, Gtk::ButtonsType::OK, true);
     err_dialog.run();
   }
-  else if (result == Gtk::PRINT_OPERATION_RESULT_APPLY)
+  else if (result == Gtk::PrintOperation::Result::APPLY)
   {
     //Update PrintSettings with the ones used in this PrintOperation:
     m_refSettings = m_refPrintFormOperation->get_print_settings();
@@ -286,7 +272,7 @@ void ExampleWindow::on_printoperation_done(Gtk::PrintOperationResult result)
   }
 }
 
-void ExampleWindow::print_or_preview(Gtk::PrintOperationAction print_action)
+void ExampleWindow::print_or_preview(Gtk::PrintOperation::Action print_action)
 {
   //Create a new PrintOperation with our PageSetup and PrintSettings:
   //(We use our derived PrintOperation class)
@@ -337,12 +323,12 @@ void ExampleWindow::on_menu_file_page_setup()
 
 void ExampleWindow::on_menu_file_print_preview()
 {
-  print_or_preview(Gtk::PRINT_OPERATION_ACTION_PREVIEW);
+  print_or_preview(Gtk::PrintOperation::Action::PREVIEW);
 }
 
 void ExampleWindow::on_menu_file_print()
 {
-  print_or_preview(Gtk::PRINT_OPERATION_ACTION_PRINT_DIALOG);
+  print_or_preview(Gtk::PrintOperation::Action::PRINT_DIALOG);
 }
 
 void ExampleWindow::on_menu_file_quit()
