@@ -27,7 +27,7 @@ PreviewDialog::PreviewDialog(
 : m_pOperation(pfo),
   m_refPreview(preview),
   m_refPrintContext(print_ctx),
-  m_VBox(Gtk::ORIENTATION_VERTICAL),
+  m_VBox(Gtk::Orientation::VERTICAL),
   m_SpinAdjustment( Gtk::Adjustment::create(1, 100, 1) ), //Used to construct m_PageSpin
   m_PageSpin(m_SpinAdjustment, 1, 0),
   m_CloseButton("_Close", true),
@@ -37,16 +37,23 @@ PreviewDialog::PreviewDialog(
 {
   set_transient_for(parent);
   set_title("Preview");
-  set_border_width(2);
+  set_size_request(300, 300);
 
+  m_VBox.set_margin(2);
   add(m_VBox);
 
-  m_HBox.pack_start(m_PageSpin);
-  m_HBox.pack_start(m_CloseButton, Gtk::PACK_SHRINK);
-  m_VBox.pack_start(m_HBox, Gtk::PACK_SHRINK);
+  m_HBox.add(m_PageSpin);
+  m_PageSpin.set_hexpand(true);
+  m_PageSpin.set_vexpand(false);
+  m_HBox.add(m_CloseButton);
+  m_VBox.add(m_HBox);
 
-  m_DrawingArea.set_size_request(200, 300);
-  m_VBox.pack_start(m_DrawingArea, Gtk::PACK_EXPAND_WIDGET);
+  m_ScrolledWindow.set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
+  m_ScrolledWindow.set_expand(true);
+  m_VBox.add(m_ScrolledWindow);
+  m_DrawingArea.set_content_width(300);
+  m_DrawingArea.set_content_height(600);
+  m_ScrolledWindow.add(m_DrawingArea);
 
   m_refPreview->signal_ready().connect(
     sigc::mem_fun(*this, &PreviewDialog::on_popreview_ready));
@@ -57,7 +64,7 @@ PreviewDialog::PreviewDialog(
   m_DrawingArea.signal_realize().connect(
     sigc::mem_fun(*this, &PreviewDialog::on_drawing_area_realized));
 
-  m_DrawingArea.signal_draw().connect(
+  m_DrawingArea.set_draw_func(
     sigc::mem_fun(*this, &PreviewDialog::on_drawing_area_draw));
 
   m_CloseButton.signal_clicked().connect(
@@ -65,8 +72,6 @@ PreviewDialog::PreviewDialog(
 
   m_PageSpin.signal_value_changed().connect(
     sigc::mem_fun(*this, &PreviewDialog::on_page_number_changed));
-
-  show_all_children();
 }
 
 PreviewDialog::~PreviewDialog()
@@ -75,14 +80,18 @@ PreviewDialog::~PreviewDialog()
 
 void PreviewDialog::on_drawing_area_realized()
 {
-  auto gdk_window = m_DrawingArea.get_window();
-  if(gdk_window)
+  auto gdk_surface = m_DrawingArea.get_surface();
+  if (gdk_surface)
   {
-    m_refDrawingContext = gdk_window->begin_draw_frame(gdk_window->get_clip_region());
-    auto cairo_ctx = m_refDrawingContext->get_cairo_context();
+    const int scale = gdk_surface->get_scale_factor();
+    const int width = gdk_surface->get_width() * scale;
+    const int height = gdk_surface->get_height() * scale;
+    auto cairo_surface = gdk_surface->create_similar_surface(
+      Cairo::Content::CONTENT_COLOR, width, height);
+    m_refCairoContext = Cairo::Context::create(cairo_surface);
 
-    if(m_refPrintContext)
-      m_refPrintContext->set_cairo_context(cairo_ctx, 72, 72);
+    if (m_refPrintContext)
+      m_refPrintContext->set_cairo_context(m_refCairoContext, 72, 72);
   }
 }
 
@@ -92,8 +101,10 @@ void PreviewDialog::on_page_number_changed()
   m_DrawingArea.queue_draw();
 }
 
-bool PreviewDialog::on_drawing_area_draw(const Cairo::RefPtr<Cairo::Context>& cr)
+void PreviewDialog::on_drawing_area_draw(const Cairo::RefPtr<Cairo::Context>& cr, int, int)
 {
+  m_refCairoContext = cr; // Can be used in on_popreview_got_page_size()
+
   Cairo::RefPtr<Cairo::Context> prev_cairo_ctx;
   double dpi_x = 72.0;
   double dpi_y = 72.0;
@@ -111,8 +122,6 @@ bool PreviewDialog::on_drawing_area_draw(const Cairo::RefPtr<Cairo::Context>& cr
 
   if(m_refPrintContext)
     m_refPrintContext->set_cairo_context(prev_cairo_ctx, dpi_x, dpi_y);
-
-  return true;
 }
 
 void PreviewDialog::on_popreview_ready(const Glib::RefPtr<Gtk::PrintContext>&)
@@ -125,10 +134,10 @@ void PreviewDialog::on_popreview_got_page_size(
                        const Glib::RefPtr<Gtk::PrintContext>& print_ctx,
                        const Glib::RefPtr<Gtk::PageSetup>& page_setup)
 {
-  const Gtk::PaperSize paper_size = page_setup->get_paper_size();
+  const auto paper_size = page_setup->get_paper_size();
 
-  const double width = paper_size.get_width(Gtk::UNIT_INCH);
-  const double height = paper_size.get_height(Gtk::UNIT_INCH);
+  const double width = paper_size.get_width(Gtk::Unit::INCH);
+  const double height = paper_size.get_height(Gtk::Unit::INCH);
 
   if(m_DrawingArea.get_realized()) //Avoid getting an odd allocation.
   {
@@ -138,12 +147,11 @@ void PreviewDialog::on_popreview_got_page_size(
     // We get a cairo context for the DrawingArea and then give that cairo
     // context to the PrintOperation's pango layout so that render_page() will
     // render into the drawing area.
-    auto cairo_ctx = m_refDrawingContext->get_cairo_context();
 
     if (fabs(dpi_x - m_DpiX) > 0.001 ||
         fabs(dpi_y - m_DpiY) > 0.001)
     {
-      print_ctx->set_cairo_context(cairo_ctx, dpi_x, dpi_y);
+      print_ctx->set_cairo_context(m_refCairoContext, dpi_x, dpi_y);
       m_DpiX = dpi_x;
       m_DpiY = dpi_y;
       m_DrawingArea.queue_draw();
@@ -153,23 +161,19 @@ void PreviewDialog::on_popreview_got_page_size(
     {
       auto layout = m_pOperation->get_pango_layout();
       if(layout)
-        layout->update_from_cairo_context(cairo_ctx);
+        layout->update_from_cairo_context(m_refCairoContext);
     }
   }
 }
 
 void PreviewDialog::on_hide()
 {
-  auto gdk_window = m_DrawingArea.get_window();
-  if(gdk_window)
-    gdk_window->end_draw_frame(m_refDrawingContext);
-
   m_refPreview->end_preview();
 
   //We will not be using these anymore, so null the RefPtrs:
   m_refPreview.reset();
   m_refPrintContext.reset();
-  m_refDrawingContext.reset();
+  m_refCairoContext.reset();
 }
 
 void PreviewDialog::on_close_clicked()
