@@ -1,5 +1,3 @@
-//$Id: timerexample.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2003 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,7 +17,7 @@
 #include "timerexample.h"
 
 TimerExample::TimerExample() :
-  m_Box(Gtk::ORIENTATION_HORIZONTAL, 10),
+  m_Box(Gtk::Orientation::HORIZONTAL, 10),
   m_ButtonAddTimer("_Add", true),
   m_ButtonDeleteTimer("_Remove", true),
   m_ButtonQuit("_Quit", true),
@@ -27,12 +25,13 @@ TimerExample::TimerExample() :
   count_value(5), // each timer will count down 5 times before disconnecting
   timeout_value(1500) // 1500 ms = 1.5 seconds
 {
-  set_border_width(10);
-
+  m_Box.set_margin(10);
   add(m_Box);
-  m_Box.pack_start(m_ButtonAddTimer);
-  m_Box.pack_start(m_ButtonDeleteTimer);
-  m_Box.pack_start(m_ButtonQuit);
+  m_Box.add(m_ButtonAddTimer);
+  m_Box.add(m_ButtonDeleteTimer);
+  m_Box.add(m_ButtonQuit);
+  for (auto child : m_Box.get_children())
+    child->set_expand();
 
   // Connect the three buttons:
   m_ButtonQuit.signal_clicked().connect(sigc::mem_fun(*this,
@@ -41,8 +40,6 @@ TimerExample::TimerExample() :
               &TimerExample::on_button_add_timer));
   m_ButtonDeleteTimer.signal_clicked().connect(sigc::mem_fun(*this,
               &TimerExample::on_button_delete_timer));
-
-  show_all_children();
 }
 
 void TimerExample::on_button_quit()
@@ -55,11 +52,11 @@ void TimerExample::on_button_add_timer()
   // Creation of a new object prevents long lines and shows us a little
   // how slots work.  We have 0 parameters and bool as a return value
   // after calling sigc::bind.
-  sigc::slot<bool> my_slot = sigc::bind(sigc::mem_fun(*this,
+  sigc::slot<bool()> my_slot = sigc::bind(sigc::mem_fun(*this,
               &TimerExample::on_timeout), m_timer_number);
 
   // This is where we connect the slot to the Glib::signal_timeout()
-  sigc::connection conn = Glib::signal_timeout().connect(my_slot,
+  auto conn = Glib::signal_timeout().connect(my_slot,
           timeout_value);
 
   // Remember the connection:
