@@ -18,7 +18,7 @@
 #include <iostream>
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
+: m_VBox(Gtk::Orientation::VERTICAL),
   m_Button_Close("_Close", true)
 {
   set_title("Gtk::Toolbar example");
@@ -28,12 +28,14 @@ ExampleWindow::ExampleWindow()
   add(m_VBox);
 
   //Put a toolbar at the top, and a button underneath:
-  m_VBox.pack_start(m_Toolbar, Gtk::PACK_SHRINK);
-  m_ButtonBox.set_border_width(5);
-  m_ButtonBox.set_layout(Gtk::BUTTONBOX_END);
-  m_VBox.pack_end(m_ButtonBox, Gtk::PACK_SHRINK);
+  m_VBox.add(m_Toolbar);
+  m_ButtonBox.set_margin(5);
+  m_VBox.add(m_ButtonBox);
 
-  m_ButtonBox.pack_start(m_Button_Close, Gtk::PACK_SHRINK);
+  m_ButtonBox.add(m_Button_Close);
+  m_Button_Close.set_expand(true);
+  m_Button_Close.set_halign(Gtk::Align::END);
+  m_Button_Close.set_valign(Gtk::Align::END);
 
   m_Button_Close.signal_clicked().connect( sigc::mem_fun(*this,
               &ExampleWindow::on_button_close) );
@@ -44,7 +46,7 @@ ExampleWindow::ExampleWindow()
     //toolbars together, because toolbar items should just be a way to do what
     //is also in a menu.
 
-    m_Toolbar.set_toolbar_style(Gtk::TOOLBAR_BOTH);
+    m_Toolbar.set_toolbar_style(Gtk::ToolbarStyle::BOTH);
 
     auto item = Gtk::make_managed<Gtk::ToolButton>("Click me");
     //item.set_tooltips(*tooltips, "Toolbar item");
@@ -73,8 +75,6 @@ ExampleWindow::ExampleWindow()
     m_Toolbar.append(*Gtk::make_managed<Gtk::RadioToolButton>(group, "Radio 2"));
     m_Toolbar.append(*Gtk::make_managed<Gtk::RadioToolButton>(group, "Radio 3"));
   }
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
