@@ -24,7 +24,7 @@ TreeView_WithPopup::TreeView_WithPopup()
   set_model(m_refTreeModel);
 
   //Fill the TreeView's model
-  Gtk::TreeModel::Row row = *(m_refTreeModel->append());
+  auto row = *(m_refTreeModel->append());
   row[m_Columns.m_col_id] = 1;
   row[m_Columns.m_col_name] = "right-click on this";
 
@@ -40,6 +40,13 @@ TreeView_WithPopup::TreeView_WithPopup()
   append_column("ID", m_Columns.m_col_id);
   append_column("Name", m_Columns.m_col_name);
 
+  // Catch button press events:
+  auto refGesture = Gtk::GestureMultiPress::create();
+  refGesture->set_button(GDK_BUTTON_SECONDARY);
+  refGesture->signal_pressed().connect(
+    sigc::mem_fun(*this, &TreeView_WithPopup::on_popup_button_pressed));
+  add_controller(refGesture);
+
   //Fill popup menu:
   auto item = Gtk::make_managed<Gtk::MenuItem>("_Edit", true);
   item->signal_activate().connect(
@@ -57,32 +64,15 @@ TreeView_WithPopup::TreeView_WithPopup()
   m_Menu_Popup.append(*item);
 
   m_Menu_Popup.accelerate(*this);
-  m_Menu_Popup.show_all(); //Show all menu items when the menu pops up
 }
 
 TreeView_WithPopup::~TreeView_WithPopup()
 {
 }
 
-bool TreeView_WithPopup::on_button_press_event(GdkEventButton* button_event)
+void TreeView_WithPopup::on_popup_button_pressed(int /* n_press */, double /* x */, double /* y */)
 {
-  bool return_value = false;
-
-  //Call base class, to allow normal handling,
-  //such as allowing the row to be selected by the right-click:
-  return_value = TreeView::on_button_press_event(button_event);
-
-  //Then do our custom stuff:
-  if( (button_event->type == GDK_BUTTON_PRESS) && (button_event->button == 3) )
-  {
-    m_Menu_Popup.popup_at_pointer((GdkEvent*)button_event);
-
-    // Menu::popup_at_pointer() is new in gtkmm 3.22.
-    // If you have an older revision, try this:
-    //m_Menu_Popup.popup(button_event->button, button_event->time);
-  }
-
-  return return_value;
+  m_Menu_Popup.popup_at_pointer();
 }
 
 void TreeView_WithPopup::on_menu_file_popup_generic()
@@ -92,7 +82,7 @@ void TreeView_WithPopup::on_menu_file_popup_generic()
   auto refSelection = get_selection();
   if(refSelection)
   {
-    Gtk::TreeModel::iterator iter = refSelection->get_selected();
+    auto iter = refSelection->get_selected();
     if(iter)
     {
       int id = (*iter)[m_Columns.m_col_id];
