@@ -1,5 +1,3 @@
-//$Id: treeview_withpopup.h 705 2006-07-19 02:55:32Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,9 +26,8 @@ public:
   virtual ~TreeView_WithPopup();
 
 protected:
-  // Override Signal handler:
-  // Alternatively, use signal_button_press_event().connect_notify()
-  bool on_button_press_event(GdkEventButton* button_event) override;
+  // Signal handler for showing popup menu:
+  void on_popup_button_pressed(int n_press, double x, double y);
 
   //Signal handler for popup menu items:
   void on_menu_file_popup_generic();
