@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,30 +18,28 @@
 #include "examplewindow.h"
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
+: m_VBox(Gtk::Orientation::VERTICAL),
   m_Button_Start("Start"),
   m_Button_Quit("_Quit", true)
 {
   set_title("update-ui example");
-  set_border_width(6);
   set_default_size(400, -1);
 
-
+  m_VBox.set_margin(6);
   add(m_VBox);
 
-  m_VBox.pack_start(m_ProgressBar, Gtk::PACK_SHRINK);
-  m_VBox.pack_start(m_ButtonBox, Gtk::PACK_SHRINK);
+  m_VBox.add(m_ProgressBar);
+  m_VBox.add(m_ButtonBox);
 
-  m_ButtonBox.pack_start(m_Button_Quit, Gtk::PACK_SHRINK);
-  m_ButtonBox.pack_start(m_Button_Start, Gtk::PACK_SHRINK);
-  m_ButtonBox.set_border_width(6);
-  m_ButtonBox.set_layout(Gtk::BUTTONBOX_END);
+  m_ButtonBox.add(m_Button_Quit);
+  m_ButtonBox.add(m_Button_Start);
+  m_ButtonBox.set_margin(6);
+  m_Button_Quit.set_hexpand(true);
+  m_Button_Quit.set_halign(Gtk::Align::END);
   m_Button_Quit.signal_clicked().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_button_quit) );
   m_Button_Start.signal_clicked().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_button_start) );
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
