@@ -46,19 +46,22 @@ CellRendererList::CellRendererList()
 {
   tree_view_.set_headers_visible(false);
   tree_view_.append_column("", popup_columns().item);
-  tree_view_.signal_button_release_event().connect(
-      sigc::mem_fun(*this, &Self::on_tree_view_button_release_event));
+
+  gesture_ = Gtk::GestureMultiPress::create();
+  gesture_->set_button(GDK_BUTTON_PRIMARY);
+  gesture_->signal_released().connect(
+    sigc::mem_fun(*this, &Self::on_tree_view_released));
+  tree_view_.add_controller(gesture_);
 
   const auto selection = tree_view_.get_selection();
-  selection->set_mode(Gtk::SELECTION_BROWSE);
+  selection->set_mode(Gtk::SelectionMode::BROWSE);
   selection->signal_changed().connect(sigc::mem_fun(*this, &Self::on_tree_selection_changed));
 
   Gtk::Frame *const frame = Gtk::make_managed<Gtk::Frame>();
   get_popup_window()->add(*frame);
 
   frame->add(tree_view_);
-  frame->set_shadow_type(Gtk::SHADOW_OUT);
-  frame->show_all();
+  frame->set_shadow_type(Gtk::ShadowType::OUT);
 
   set_focus_widget(tree_view_);
 }
@@ -68,13 +71,13 @@ CellRendererList::~CellRendererList()
 
 void CellRendererList::append_list_item(const Glib::ustring& text)
 {
-  Gtk::TreeModel::Row row = *list_store_->append();
+  auto row = *list_store_->append();
   row[popup_columns().item] = text;
 }
 
 Glib::ustring CellRendererList::get_selected_item()
 {
-  if(const Gtk::TreeModel::iterator selected = tree_view_.get_selection()->get_selected())
+  if(const auto selected = tree_view_.get_selection()->get_selected())
   {
     return (*selected)[popup_columns().item];
   }
@@ -89,15 +92,9 @@ void CellRendererList::on_show_popup(const Glib::ustring& path, int x1, int y1,
   CellRendererPopup::on_show_popup(path, x1, y1, x2, y2);
 }
 
-bool CellRendererList::on_tree_view_button_release_event(GdkEventButton* event)
+void CellRendererList::on_tree_view_released(int /* n_press */, double /* x */, double /* y */)
 {
-  if(event->button == 1)
-  {
-    hide_popup();
-    return true;
-  }
-
-  return false;
+  hide_popup();
 }
 
 void CellRendererList::on_tree_selection_changed()
