@@ -1,5 +1,3 @@
-//$Id: cellrendererlist.h 156 2004-03-12 10:11:35Z murrayc $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -39,8 +37,9 @@ private:
 
   Glib::RefPtr<Gtk::ListStore>  list_store_;
   Gtk::TreeView                 tree_view_;
+  Glib::RefPtr<Gtk::GestureMultiPress> gesture_;
 
-  bool on_tree_view_button_release_event(GdkEventButton* event);
+  void on_tree_view_released(int n_press, double x, double y);
   void on_tree_selection_changed();
 };
 
