@@ -23,7 +23,7 @@
 namespace
 {
 
-bool grab_on_window(const Glib::RefPtr<Gdk::Window>& window)
+bool grab_on_window(const Glib::RefPtr<Gdk::Surface>& surface)
 {
   Glib::RefPtr<Gdk::Device> device (Glib::wrap(gtk_get_current_event_device(), true));
 
@@ -31,7 +31,7 @@ bool grab_on_window(const Glib::RefPtr<Gdk::Window>& window)
   {
     auto seat = device->get_seat();
     if (seat &&
-        seat->grab(window, Gdk::SEAT_CAPABILITY_ALL, true) == Gdk::GRAB_SUCCESS)
+        seat->grab(surface, Gdk::Seat::Capabilities::ALL, true) == Gdk::GrabStatus::SUCCESS)
       return true;
   }
 
@@ -46,7 +46,7 @@ CellRendererPopup::CellRendererPopup()
   Glib::ObjectBase      (typeid(CellRendererPopup)),
   Gtk::CellRendererText (),
   button_width_         (-1),
-  popup_window_         (Gtk::WINDOW_POPUP),
+  popup_window_         (Gtk::WindowType::POPUP),
   focus_widget_         (nullptr),
   popup_entry_          (nullptr),
   shown_                (false),
@@ -55,9 +55,18 @@ CellRendererPopup::CellRendererPopup()
   signal_show_popup_.connect(sigc::mem_fun(*this, &Self::on_show_popup));
   signal_hide_popup_.connect(sigc::mem_fun(*this, &Self::on_hide_popup));
 
-  popup_window_.signal_button_press_event().connect(sigc::mem_fun(*this, &Self::on_button_press_event));
-  popup_window_.signal_key_press_event   ().connect(sigc::mem_fun(*this, &Self::on_key_press_event));
-  //TODO: popup_window_.signal_style_changed     ().connect(sigc::mem_fun(*this, &Self::on_style_changed));
+  gesture_ = Gtk::GestureMultiPress::create();
+  gesture_->set_button(GDK_BUTTON_PRIMARY);
+  gesture_->signal_pressed().connect(
+    sigc::mem_fun(*this, &Self::on_popup_window_pressed));
+  popup_window_.add_controller(gesture_);
+
+  auto controller = Gtk::EventControllerKey::create();
+  controller->signal_key_pressed().connect(
+    sigc::mem_fun(*this, &Self::on_popup_window_key_pressed), true);
+  popup_window_.add_controller(controller);
+
+  popup_window_.signal_style_updated().connect(sigc::mem_fun(*this, &Self::on_style_updated));
 }
 
 CellRendererPopup::~CellRendererPopup()
@@ -98,25 +107,34 @@ void CellRendererPopup::hide_popup()
   signal_hide_popup_();
 }
 
-//TODO: Port this to gtkmm 3:
-/*
-void CellRendererPopup::get_preferred_size_vfunc(Gtk::Widget& widget,
-                                       const Gdk::Rectangle* cell_area,
-                                       int* x_offset, int* y_offset,
-                                       int* width,    int* height) const
+void CellRendererPopup::get_preferred_width_vfunc(Gtk::Widget& widget,
+  int& minimum_width, int& natural_width) const
 {
-  Gtk::CellRendererText::get_preferred_size_vfunc(widget, cell_area, x_offset, y_offset, width, height);
+  Gtk::CellRendererText::get_preferred_width_vfunc(widget, minimum_width, natural_width);
 
   // We cache this because it takes a really long time to get the width.
-  if(button_width_ < 0)
+  if (button_width_ < 0)
     button_width_ = PopupEntry::get_button_width();
 
-  if(width)
-    *width += button_width_;
+  minimum_width += button_width_;
+  natural_width += button_width_;
 }
-*/
 
-Gtk::CellEditable* CellRendererPopup::start_editing_vfunc(GdkEvent*,
+void CellRendererPopup::get_preferred_width_for_height_vfunc(Gtk::Widget& widget,
+  int height, int& minimum_width, int& natural_width) const
+{
+  Gtk::CellRendererText::get_preferred_width_for_height_vfunc(
+    widget, height, minimum_width, natural_width);
+
+  // We cache this because it takes a really long time to get the width.
+  if (button_width_ < 0)
+    button_width_ = PopupEntry::get_button_width();
+
+  minimum_width += button_width_;
+  natural_width += button_width_;
+}
+
+Gtk::CellEditable* CellRendererPopup::start_editing_vfunc(const Glib::RefPtr<const Gdk::Event>&,
                                                           Gtk::Widget&,
                                                           const Glib::ustring& path,
                                                           const Gdk::Rectangle&,
@@ -147,10 +165,13 @@ void CellRendererPopup::on_show_popup(const Glib::ustring&, int, int y1, int x2,
 {
   // I'm not sure this is ok to do, but we need to show the window to be
   // able to get the allocation right.
-  popup_window_.move(-500, -500);
+  // 2019-04-07: gtk_window_move() and Gtk::Window::move() have been removed.
+  // Use set_position() for the time being.
+  //popup_window_.move(-500, -500);
+  popup_window_.set_position(Gtk::WindowPosition::MOUSE);
   popup_window_.show();
 
-  const Gtk::Allocation alloc = popup_window_.get_allocation();
+  const auto alloc = popup_window_.get_allocation();
 
   int x = x2;
   int y = y2;
@@ -186,7 +207,8 @@ void CellRendererPopup::on_show_popup(const Glib::ustring&, int, int y1, int x2,
 
   popup_window_.add_modal_grab();
 
-  popup_window_.move(x, y);
+  //popup_window_.move(x, y);
+  (void)x; (void)y; // Pretend that x and y are used.
   popup_window_.show();
 
   shown_ = true;
@@ -194,7 +216,7 @@ void CellRendererPopup::on_show_popup(const Glib::ustring&, int, int y1, int x2,
   if(focus_widget_)
     focus_widget_->grab_focus();
 
-  grab_on_window(popup_window_.get_window());
+  grab_on_window(popup_window_.get_surface());
 }
 
 void CellRendererPopup::on_hide_popup()
@@ -214,21 +236,26 @@ void CellRendererPopup::on_hide_popup()
   editing_canceled_ = false;
 }
 
-bool CellRendererPopup::on_button_press_event(GdkEventButton* event)
+void CellRendererPopup::on_popup_window_pressed(int /* n_press */, double /* x */, double /* y */)
 {
-  if(event->button != 1)
-    return false;
-
   // If the event happened outside the popup, cancel editing.
 
-  //gdk_event_get_root_coords ((GdkEvent *) event, &x, &y);
-  const double x = event->x_root;
-  const double y = event->y_root;
+  // The (x,y) coords passed to this method are based on Gdk::EventButton::get_coords(),
+  // which can't be trusted when input is grabbed by the popup window.
+  // Use Gdk::EventButton::get_root_coords().
+
+  auto event = gesture_->get_last_event(gesture_->get_current_sequence());
+  if (!(event && event->get_event_type() == Gdk::Event::Type::BUTTON_PRESS))
+    return;
+
+  double x = 0.0;
+  double y = 0.0;
+  std::static_pointer_cast<const Gdk::EventButton>(event)->get_root_coords(x, y);
 
   int xoffset = 0, yoffset = 0;
-  popup_window_.get_window()->get_root_origin(xoffset, yoffset);
+  popup_window_.get_surface()->get_root_origin(xoffset, yoffset);
 
-  const Gtk::Allocation alloc = popup_window_.get_allocation();
+  const auto alloc = popup_window_.get_allocation();
 
   xoffset += alloc.get_x();
   yoffset += alloc.get_y();
@@ -239,17 +266,15 @@ bool CellRendererPopup::on_button_press_event(GdkEventButton* event)
   const int y2 = y1 + alloc.get_height();
 
   if(x > x1 && x < x2 && y > y1 && y < y2)
-    return false;
+    return;
 
   editing_canceled_ = true;
   signal_hide_popup_();
-
-  return false;
 }
 
-bool CellRendererPopup::on_key_press_event(GdkEventKey* event)
+bool CellRendererPopup::on_popup_window_key_pressed(guint keyval, guint, Gdk::ModifierType)
 {
-  switch(event->keyval)
+  switch (keyval)
   {
     case GDK_KEY_Escape:
       editing_canceled_ = true; break;
@@ -269,7 +294,7 @@ bool CellRendererPopup::on_key_press_event(GdkEventKey* event)
   return true;
 }
 
-void CellRendererPopup::on_style_changed(const Glib::RefPtr<Gtk::Style>&)
+void CellRendererPopup::on_style_updated()
 {
   // Invalidate the cache.
   button_width_ = -1;
@@ -292,15 +317,15 @@ void CellRendererPopup::on_popup_arrow_clicked()
     return;
   }
 
-  if(!grab_on_window(popup_entry_->get_window()))
+  if(!grab_on_window(popup_entry_->get_surface()))
     return;
 
   popup_entry_->select_region(0, 0);
 
   int x = 0, y = 0;
-  popup_entry_->get_window()->get_origin(x, y);
+  popup_entry_->get_surface()->get_origin(x, y);
 
-  const Gtk::Allocation alloc = popup_entry_->get_allocation();
+  const auto alloc = popup_entry_->get_allocation();
 
   signal_show_popup_(popup_entry_->get_path(), x, y, x + alloc.get_width(), y + alloc.get_height());
 }
