@@ -1,5 +1,3 @@
-//$Id: cellrendererpopup.h 156 2004-03-12 10:11:35Z murrayc $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,7 +25,7 @@ class CellRendererPopup : public Gtk::CellRendererText
 {
 public:
   CellRendererPopup();
-  virtual ~CellRendererPopup();
+  ~CellRendererPopup() override;
 
   PopupEntry*  get_popup_entry();
   Gtk::Window* get_popup_window();
@@ -35,38 +33,34 @@ public:
   void set_focus_widget(Gtk::Widget& focus_widget);
   Gtk::Widget* get_focus_widget();
 
-  typedef sigc::signal<void,const Glib::ustring&,int,int,int,int> SignalShowPopup;
+  using SignalShowPopup = sigc::signal<void(const Glib::ustring&,int,int,int,int)>;
   SignalShowPopup& signal_show_popup();
 
-  typedef sigc::signal<void> SignalHidePopup;
+  using SignalHidePopup = sigc::signal<void()>;
   SignalHidePopup& signal_hide_popup();
 
   void hide_popup();
 
 protected:
+  void get_preferred_width_vfunc(Gtk::Widget& widget,
+    int& minimum_width, int& natural_width) const override;
+  void get_preferred_width_for_height_vfunc(Gtk::Widget& widget, int height,
+    int& minimum_width, int& natural_width) const override;
 
-  //TODO: Port this to gtkmm 3:
-  /*
-  void get_preferred_size_vfunc(Gtk::Widget& widget,
-                              const Gdk::Rectangle* cell_area,
-                              int* x_offset, int* y_offset,
-                              int* width,    int* height) const  override;
-  */
-
-  Gtk::CellEditable* start_editing_vfunc(GdkEvent* event,
-                                                 Gtk::Widget& widget,
-                                                 const Glib::ustring& path,
-                                                 const Gdk::Rectangle& background_area,
-                                                 const Gdk::Rectangle& cell_area,
-                                                 Gtk::CellRendererState flags) override;
+  Gtk::CellEditable* start_editing_vfunc(const Glib::RefPtr<const Gdk::Event>& event,
+                                         Gtk::Widget& widget,
+                                         const Glib::ustring& path,
+                                         const Gdk::Rectangle& background_area,
+                                         const Gdk::Rectangle& cell_area,
+                                         Gtk::CellRendererState flags) override;
 
   virtual void on_show_popup(const Glib::ustring& path, int x1, int y1, int x2, int y2);
   void on_hide_popup();
 
 private:
-  typedef CellRendererPopup Self;
+  using Self = CellRendererPopup;
 
-  SignalShowPopup  signal_show_popup_;
+  SignalShowPopup signal_show_popup_;
   SignalHidePopup signal_hide_popup_;
 
   mutable int   button_width_; //mutable because it is just a cache.
@@ -75,10 +69,11 @@ private:
   PopupEntry*   popup_entry_;
   bool          shown_;
   bool          editing_canceled_;
+  Glib::RefPtr<Gtk::GestureMultiPress> gesture_;
 
-  bool on_button_press_event(GdkEventButton* event);
-  bool on_key_press_event(GdkEventKey* event);
-  void on_style_changed(const Glib::RefPtr<Gtk::Style>& previous_style);
+  void on_popup_window_pressed(int n_press, double x, double y);
+  bool on_popup_window_key_pressed(guint keyval, guint keycode, Gdk::ModifierType state);
+  void on_style_updated();
 
   void on_popup_editing_done();
   void on_popup_arrow_clicked();
