@@ -23,7 +23,7 @@ DnDWindow::DnDWindow()
 : m_Label_Drop("Drop here\n"), m_Label_Popup("Popup\n"),
   m_Button("Drag Here\n"),
   m_have_drag(false),
-  m_PopupWindow(Gtk::WINDOW_POPUP)
+  m_PopupWindow(Gtk::WindowType::POPUP)
 {
   m_popped_up = false;
   m_in_popup = false;
@@ -35,50 +35,57 @@ DnDWindow::DnDWindow()
   m_trashcan_closed = Gdk::Pixbuf::create_from_xpm_data(trashcan_closed_xpm);
 
   //Targets:
-  m_listTargets.push_back( Gtk::TargetEntry("STRING", Gtk::TargetFlags(0), TARGET_STRING) );
-  m_listTargets.push_back( Gtk::TargetEntry("text/plain", Gtk::TargetFlags(0), TARGET_STRING) );
-  m_listTargets.push_back( Gtk::TargetEntry("application/x-rootwin-drop", Gtk::TargetFlags(0), TARGET_ROOTWIN) );
+  m_listTargets.push_back("STRING");
+  m_listTargets.push_back("text/plain");
+  m_listTargets.push_back("text/plain;charset=utf-8");
+  if (!Glib::get_charset())
+  {
+    std::string charset;
+    Glib::get_charset(charset);
+    m_listTargets.push_back("text/plain;charset=" + charset);
+  }
+  m_listTargets.push_back("application/x-rootwin-drop");
 
   //Targets without rootwin:
   m_listTargetsNoRoot.assign(m_listTargets.begin(), --m_listTargets.end());
 
-  m_Label_Drop.drag_dest_set(m_listTargetsNoRoot, Gtk::DEST_DEFAULT_ALL, Gdk::DragAction(GDK_ACTION_COPY | GDK_ACTION_MOVE));
+  m_Label_Drop.drag_dest_set(Gdk::ContentFormats::create(m_listTargetsNoRoot), Gtk::DestDefaults::ALL, Gdk::DragAction::COPY | Gdk::DragAction::MOVE);
 
   m_Label_Drop.signal_drag_data_received().connect( sigc::mem_fun(*this, &DnDWindow::on_label_drop_drag_data_received) );
 
-  m_Grid.attach(m_Label_Drop, 0, 0, 1, 1);
+  m_Grid.attach(m_Label_Drop, 0, 0);
   m_Label_Drop.set_hexpand(true);
   m_Label_Drop.set_vexpand(true);
 
-  m_Label_Popup.drag_dest_set(m_listTargetsNoRoot, Gtk::DEST_DEFAULT_ALL, Gdk::DragAction(GDK_ACTION_COPY | GDK_ACTION_MOVE));
+  m_Label_Popup.drag_dest_set(Gdk::ContentFormats::create(m_listTargetsNoRoot), Gtk::DestDefaults::ALL, Gdk::DragAction::COPY | Gdk::DragAction::MOVE);
 
-  m_Grid.attach(m_Label_Popup, 1, 1, 1, 1);
+  m_Grid.attach(m_Label_Popup, 1, 1);
   m_Label_Popup.set_hexpand(true);
   m_Label_Popup.set_vexpand(true);
 
-  m_Label_Popup.signal_drag_motion().connect( sigc::mem_fun(*this, &DnDWindow::on_label_popup_drag_motion) );
+  m_Label_Popup.signal_drag_motion().connect( sigc::mem_fun(*this, &DnDWindow::on_label_popup_drag_motion), true );
   m_Label_Popup.signal_drag_leave().connect( sigc::mem_fun(*this, &DnDWindow::on_label_popup_drag_leave) );
 
   m_Image.set(m_trashcan_closed);
   m_Image.drag_dest_set();
 
-  m_Grid.attach(m_Image, 1, 0, 1, 1);
+  m_Grid.attach(m_Image, 1, 0);
   m_Image.set_hexpand(true);
   m_Image.set_vexpand(true);
 
   m_Image.signal_drag_leave().connect( sigc::mem_fun(*this, &DnDWindow::on_image_drag_leave) );
-  m_Image.signal_drag_motion().connect( sigc::mem_fun(*this, &DnDWindow::on_image_drag_motion) );
-  m_Image.signal_drag_drop().connect( sigc::mem_fun(*this, &DnDWindow::on_image_drag_drop) );
+  m_Image.signal_drag_motion().connect( sigc::mem_fun(*this, &DnDWindow::on_image_drag_motion), true );
+  m_Image.signal_drag_drop().connect( sigc::mem_fun(*this, &DnDWindow::on_image_drag_drop), true );
   m_Image.signal_drag_data_received().connect( sigc::mem_fun(*this, &DnDWindow::on_image_drag_data_received) );
 
   /* Drag site */
 
-  m_Button.drag_source_set(m_listTargets, Gdk::ModifierType(GDK_BUTTON1_MASK | GDK_BUTTON3_MASK),
-                           Gdk::DragAction(GDK_ACTION_COPY | GDK_ACTION_MOVE));
+  m_Button.drag_source_set(Gdk::ContentFormats::create(m_listTargets), Gdk::ModifierType::BUTTON1_MASK | Gdk::ModifierType::BUTTON3_MASK,
+                           Gdk::DragAction::COPY | Gdk::DragAction::MOVE);
 
-  m_Button.drag_source_set_icon(m_drag_icon);
+  m_Button.drag_source_set_icon(Gdk::Texture::create_for_pixbuf(m_drag_icon));
 
-  m_Grid.attach(m_Button, 0, 1, 1, 1);
+  m_Grid.attach(m_Button, 0, 1);
   m_Button.set_hexpand(true);
   m_Button.set_vexpand(true);
 
@@ -86,8 +93,6 @@ DnDWindow::DnDWindow()
   m_Button.signal_drag_data_delete().connect( sigc::mem_fun(*this, &DnDWindow::on_button_drag_data_delete));
 
   create_popup();
-
-  show_all();
 }
 
 DnDWindow::~DnDWindow()
@@ -95,7 +100,7 @@ DnDWindow::~DnDWindow()
 }
 
 
-void DnDWindow::on_label_drop_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int, int, const Gtk::SelectionData& selection_data, guint, guint time)
+void DnDWindow::on_label_drop_drag_data_received(const Glib::RefPtr<Gdk::Drop>& drop, const Gtk::SelectionData& selection_data)
 {
   const int length = selection_data.get_length();
   const guchar* data = selection_data.get_data();
@@ -105,10 +110,10 @@ void DnDWindow::on_label_drop_drag_data_received(const Glib::RefPtr<Gdk::DragCon
     g_print ("Received \"%s\" in label\n", (gchar *)data);
   }
 
-  context->drag_finish(false, false, time);
+  drop->failed();
 }
 
-bool DnDWindow::on_label_popup_drag_motion(const Glib::RefPtr<Gdk::DragContext>&, int, int, guint)
+bool DnDWindow::on_label_popup_drag_motion(const Glib::RefPtr<Gdk::Drop>&, int, int)
 {
   if(!m_popup_timer)
     m_popup_timer = Glib::signal_timeout().connect( sigc::mem_fun(*this, &DnDWindow::on_popup_timeout), 500);
@@ -116,7 +121,7 @@ bool DnDWindow::on_label_popup_drag_motion(const Glib::RefPtr<Gdk::DragContext>&
   return true;
 }
 
-void DnDWindow::on_label_popup_drag_leave(const Glib::RefPtr<Gdk::DragContext>&, guint)
+void DnDWindow::on_label_popup_drag_leave(const Glib::RefPtr<Gdk::Drop>&)
 {
  if(m_in_popup)
  {
@@ -129,7 +134,7 @@ void DnDWindow::on_label_popup_drag_leave(const Glib::RefPtr<Gdk::DragContext>&,
  }
 }
 
-void DnDWindow::on_image_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int, int, const Gtk::SelectionData& selection_data, guint, guint time)
+void DnDWindow::on_image_drag_data_received(const Glib::RefPtr<Gdk::Drop>& drop, const Gtk::SelectionData& selection_data)
 {
   const int length = selection_data.get_length();
   const guchar* data = selection_data.get_data();
@@ -139,10 +144,10 @@ void DnDWindow::on_image_drag_data_received(const Glib::RefPtr<Gdk::DragContext>
     g_print ("Received \"%s\" in trashcan\n", (gchar*)data);
   }
 
-  context->drag_finish(false, false, time);
+  drop->failed();
 }
 
-bool DnDWindow::on_image_drag_motion(const Glib::RefPtr<Gdk::DragContext>& context, int, int, guint time)
+bool DnDWindow::on_image_drag_motion(const Glib::RefPtr<Gdk::Drop>& drop, int, int)
 {
   if(!m_have_drag)
   {
@@ -150,54 +155,54 @@ bool DnDWindow::on_image_drag_motion(const Glib::RefPtr<Gdk::DragContext>& conte
     m_Image.set(m_trashcan_open);
   }
 
-  auto source_widget = Gtk::Widget::drag_get_source_widget(context);
+  auto source_widget = Gtk::DnD::get_source_widget(drop->get_drag());
   g_print ("motion, source %s\n", source_widget ?
            G_OBJECT_TYPE_NAME (source_widget) :
            "NULL");
 
-  for(const auto& name : context->list_targets())
+  for(const auto& name : drop->get_formats()->get_mime_types())
   {
     g_print ("%s\n", name.c_str());
   }
 
-  context->drag_status(context->get_suggested_action(), time);
+  drop->status(drop->get_drag()->get_selected_action());
   return true;
 }
 
-void DnDWindow::on_image_drag_leave(const Glib::RefPtr<Gdk::DragContext>&, guint)
+void DnDWindow::on_image_drag_leave(const Glib::RefPtr<Gdk::Drop>&)
 {
   g_print("leave\n");
   m_have_drag = false;
   m_Image.set(m_trashcan_closed);
 }
 
-bool DnDWindow::on_image_drag_drop(const Glib::RefPtr<Gdk::DragContext>& context, int, int, guint time)
+bool DnDWindow::on_image_drag_drop(const Glib::RefPtr<Gdk::Drop>& drop, int, int)
 {
   g_print("drop\n");
   m_have_drag = false;
 
   m_Image.set(m_trashcan_closed);
 
-  std::vector<std::string> targets = context->list_targets();
+  const auto targets = drop->get_formats()->get_mime_types();
   if(!targets.empty())
   {
-    drag_get_data( context, Glib::ustring(targets[0]), time );
+    m_Image.drag_get_data(drop, targets[0]);
   }
 
   return true;
 }
 
 
-void DnDWindow::on_button_drag_data_get(const Glib::RefPtr<Gdk::DragContext>&, Gtk::SelectionData& selection_data, guint info, guint)
+void DnDWindow::on_button_drag_data_get(const Glib::RefPtr<Gdk::Drag>&, Gtk::SelectionData& selection_data)
 {
-  if(info == TARGET_ROOTWIN)
+  if(selection_data.get_target() == "application/x-rootwin-drop")
     g_print ("I was dropped on the rootwin\n");
   else
     selection_data.set(selection_data.get_target(),
                        8 /* 8-bits format */, (const guchar*)"I'm Data!", 9 /* The length of I'm Data in bytes */);
 }
 
-void DnDWindow::on_button_drag_data_delete(const Glib::RefPtr<Gdk::DragContext>&)
+void DnDWindow::on_button_drag_data_delete(const Glib::RefPtr<Gdk::Drag>&)
 {
   g_print ("Delete the data!\n");
 }
@@ -230,7 +235,7 @@ bool DnDWindow::on_popup_timeout()
 
 void DnDWindow::create_popup()
 {
-  m_PopupWindow.set_position(Gtk::WIN_POS_MOUSE);
+  m_PopupWindow.set_position(Gtk::WindowPosition::MOUSE);
 
   //Create Grid and fill it:
   auto pGrid = Gtk::make_managed<Gtk::Grid>();
@@ -242,18 +247,18 @@ void DnDWindow::create_popup()
       char buffer[128];
       g_snprintf(buffer, sizeof(buffer), "%d,%d", i, j);
       auto pButton = Gtk::make_managed<Gtk::Button>(buffer);
-      pGrid->attach(*pButton, i, j);
+      pGrid->attach(*pButton, i, j, 1, 1);
 
-      pButton->drag_dest_set(m_listTargetsNoRoot, Gtk::DEST_DEFAULT_ALL, Gdk::DragAction(GDK_ACTION_COPY | GDK_ACTION_MOVE));
-      pButton->signal_drag_motion().connect( sigc::mem_fun(*this, &DnDWindow::on_popup_button_drag_motion) );                      pButton->signal_drag_leave().connect( sigc::mem_fun(*this, &DnDWindow::on_popup_button_drag_leave) );
+      pButton->drag_dest_set(Gdk::ContentFormats::create(m_listTargetsNoRoot), Gtk::DestDefaults::ALL, Gdk::DragAction::COPY | Gdk::DragAction::MOVE);
+      pButton->signal_drag_motion().connect( sigc::mem_fun(*this, &DnDWindow::on_popup_button_drag_motion), true );
+      pButton->signal_drag_leave().connect( sigc::mem_fun(*this, &DnDWindow::on_popup_button_drag_leave) );
     }
   }
 
-  pGrid->show_all();
   m_PopupWindow.add(*pGrid);
 }
 
-bool DnDWindow::on_popup_button_drag_motion(const Glib::RefPtr<Gdk::DragContext>&, int, int, guint)
+bool DnDWindow::on_popup_button_drag_motion(const Glib::RefPtr<Gdk::Drop>&, int, int)
 {
   if(!m_in_popup)
   {
@@ -268,7 +273,7 @@ bool DnDWindow::on_popup_button_drag_motion(const Glib::RefPtr<Gdk::DragContext>
   return true;
 }
 
-void DnDWindow::on_popup_button_drag_leave(const Glib::RefPtr<Gdk::DragContext>&, guint)
+void DnDWindow::on_popup_button_drag_leave(const Glib::RefPtr<Gdk::Drop>&)
 {
  if(m_in_popup)
  {
